aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorJack Bracewell <jbtwentythree@gmail.com>2017-03-24 16:36:46 +0000
committerBjörn Linse <bjorn.linse@gmail.com>2018-06-13 17:54:16 +0200
commita7bb63c55dacfa822e1a24d041771d9e8d83a980 (patch)
tree78ab8f42c2470f7a810b9327e18596a9973f030a /src
parent463da8480685dbd53335b4e3f0a6d37cacbacac4 (diff)
downloadrneovim-a7bb63c55dacfa822e1a24d041771d9e8d83a980.tar.gz
rneovim-a7bb63c55dacfa822e1a24d041771d9e8d83a980.tar.bz2
rneovim-a7bb63c55dacfa822e1a24d041771d9e8d83a980.zip
Add ‘eob’ option to fillchars
This option allows configuring what character is shown on the empty lines at the end of a buffer, previously hardcoded to ‘~’
Diffstat (limited to 'src')
-rw-r--r--src/nvim/globals.h1
-rw-r--r--src/nvim/option.c1
-rw-r--r--src/nvim/screen.c6
3 files changed, 5 insertions, 3 deletions
diff --git a/src/nvim/globals.h b/src/nvim/globals.h
index 20e5353b51..f5ebaa9753 100644
--- a/src/nvim/globals.h
+++ b/src/nvim/globals.h
@@ -908,6 +908,7 @@ EXTERN int fill_vert INIT(= 9474); // │
EXTERN int fill_fold INIT(= 183); // ·
EXTERN int fill_diff INIT(= '-');
EXTERN int fill_msgsep INIT(= ' ');
+EXTERN int fill_eob INIT(= '~');
/* Whether 'keymodel' contains "stopsel" and "startsel". */
EXTERN int km_stopsel INIT(= FALSE);
diff --git a/src/nvim/option.c b/src/nvim/option.c
index a7ee0ef28b..3c1a70e90d 100644
--- a/src/nvim/option.c
+++ b/src/nvim/option.c
@@ -3386,6 +3386,7 @@ static char_u *set_chars_option(char_u **varp)
{ &fill_fold, "fold" , 183 }, // ·
{ &fill_diff, "diff" , '-' },
{ &fill_msgsep, "msgsep", ' ' },
+ { &fill_eob, "eob", '~' },
};
static struct charstab lcstab[] = {
{ &lcs_eol, "eol", NUL },
diff --git a/src/nvim/screen.c b/src/nvim/screen.c
index cf9a72715b..80f7a32c07 100644
--- a/src/nvim/screen.c
+++ b/src/nvim/screen.c
@@ -1532,9 +1532,9 @@ static void win_update(win_T *wp)
} else if (dollar_vcol == -1)
wp->w_botline = lnum;
- /* make sure the rest of the screen is blank */
- /* put '~'s on rows that aren't part of the file. */
- win_draw_end(wp, '~', ' ', row, wp->w_height, HLF_EOB);
+ // make sure the rest of the screen is blank
+ // write the 'fill_eob' character to rows that aren't part of the file.
+ win_draw_end(wp, fill_eob, ' ', row, wp->w_height, HLF_EOB);
}
/* Reset the type of redrawing required, the window has been updated. */